/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file Logger.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_LOGGER_H
#define GMIC_QT_LOGGER_H

#include <cstdio>
#include "gmic_qt.h"

class QString;

class Logger {
public:
  enum Mode
  {
    StandardOutput,
    File
  };

  static void setMode(const Mode mode);
  static void setMode(const GmicQt::OutputMessageMode mode);
  static void clear();
  static void close();
  static void log(const QString & message, const QString & hint, bool space = false);
  static void error(const QString & message, bool space = false);
  static void warning(const QString & message, bool space = false);
  static void note(const QString & message, bool space = false);
  static void log(const QString & message, bool space = false);
  Logger() = delete;

private:
  static FILE * _logFile;
  static Mode _currentMode;
};

#endif // GMIC_QT_LOGGER_H
